==> mingw-w64-freecad-1.0rc1-1.src.tar.zst: FreeCAD-1.0rc1/src/Mod/Start/Gui/Resources/translations/StartPage_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en">
  <context>
    <name>StartGui::FirstStartWidget</name>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="95"/>
      <source>Done</source>
      <translation>Hotovo</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="97"/>
      <source>Welcome to %1</source>
      <translation>Vítejte ve %1</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="100"/>
      <source>To get started, set your basic configuration options below.</source>
      <translation>Níže začněte s nastavením základních vlastností programu.</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="101"/>
      <source>These options (and many more) can be changed later in Preferences.</source>
      <translation>Tyto možnosti (a mnoho dalších) lze později změnit v nastavení.</translation>
    </message>
  </context>
  <context>
    <name>StartGui::GeneralSettingsWidget</name>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="212"/>
      <source>Language</source>
      <translation>Jazyk</translation>
    </message>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="213"/>
      <source>Unit System</source>
      <translation>Jednotky</translation>
    </message>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="226"/>
      <source>Navigation Style</source>
      <translation>Styl navigace</translation>
    </message>
  </context>
  <context>
    <name>CmdStart</name>
    <message>
      <location filename="../../Manipulator.cpp" line="47"/>
      <location filename="../../Manipulator.cpp" line="48"/>
      <source>Start</source>
      <translation>Start</translation>
    </message>
    <message>
      <location filename="../../Manipulator.cpp" line="49"/>
      <source>Displays the Start in an MDI view</source>
      <translation>Zobrazí start v zobrazení MDI</translation>
    </message>
  </context>
  <context>
    <name>StartGui::StartView</name>
    <message>
      <location filename="../../StartView.cpp" line="208"/>
      <source>Empty file</source>
      <translation>Prázdný soubor</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="209"/>
      <source>Create a new empty FreeCAD file</source>
      <translation>Vytvořit prázdný soubor FreeCADu</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="211"/>
      <source>Open File</source>
      <translation>Otevřít soubor</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="212"/>
      <source>Open an existing CAD file or 3D model</source>
      <translation>Otevřít existující CAD soubor nebo 3D model</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="214"/>
      <source>Parametric Part</source>
      <translation>Parametrický díl</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="215"/>
      <source>Create a part with the Part Design workbench</source>
      <translation>Vytvořit díl v prostředí návrhu dílu</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="217"/>
      <source>Assembly</source>
      <translation>Sestava</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="218"/>
      <source>Create an assembly project</source>
      <translation>Vytvořit projekt sestavy</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="220"/>
      <source>2D Draft</source>
      <translation>2D návrh</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="221"/>
      <source>Create a 2D Draft with the Draft workbench</source>
      <translation>Vytvořit 2D návrh v prostředí návrhu</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="223"/>
      <source>BIM/Architecture</source>
      <translation>BIM/Architektura</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="224"/>
      <source>Create an architectural project</source>
      <translation>Vytvořit projekt architektury</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="488"/>
      <source>New File</source>
      <translation>Nový soubor</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="489"/>
      <source>Examples</source>
      <translation>Příklady</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="490"/>
      <source>Recent Files</source>
      <translation>Nedávné soubory</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="493"/>
      <source>Open first start setup</source>
      <translation type="unfinished">Open first start setup</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="495"/>
      <source>Don't show this Start page again (start with blank screen)</source>
      <translation>Nezobrazovat příště tuto úvodní stránku (začít s prázdnou obrazovkou)</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../StartView.cpp" line="482"/>
      <source>Start</source>
      <translation>Start</translation>
    </message>
  </context>
  <context>
    <name>StartGui::ThemeSelectorWidget</name>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="58"/>
      <source>FreeCAD Classic</source>
      <translation>Klasický FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="59"/>
      <source>FreeCAD Dark</source>
      <translation>Tmavý FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="60"/>
      <source>FreeCAD Light</source>
      <translation>Světlý FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="166"/>
      <source>Theme</source>
      <translation>Motiv</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="167"/>
      <source>Looking for more themes? You can obtain them using &lt;a href="freecad:Std_AddonMgr"&gt;Addon Manager&lt;/a&gt;.</source>
      <translation>Hledáte více motivů? Můžete je získat prostřednictvím &lt;a href="freecad:Std_AddonMgr"&gt;Správce doplňků&lt;/a&gt;.</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="169"/>
      <source>FreeCAD Dark</source>
      <comment>Visual theme name</comment>
      <translation>Tmavý FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="170"/>
      <source>FreeCAD Light</source>
      <comment>Visual theme name</comment>
      <translation>Světlý FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="171"/>
      <source>FreeCAD Classic</source>
      <comment>Visual theme name</comment>
      <translation>Klasický FreeCAD</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0.0-3.src.tar.zst: FreeCAD-1.0.0/src/Mod/Start/Gui/Resources/translations/StartPage_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en">
  <context>
    <name>StartGui::FirstStartWidget</name>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="94"/>
      <source>Done</source>
      <translation>Hotovo</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="96"/>
      <source>Welcome to %1</source>
      <translation>Vítejte ve %1</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="99"/>
      <source>To get started, set your basic configuration options below.</source>
      <translation>Níže začněte s nastavením základních vlastností programu.</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="100"/>
      <source>These options (and many more) can be changed later in Preferences.</source>
      <translation>Tyto možnosti (a mnoho dalších) lze později změnit v nastavení.</translation>
    </message>
  </context>
  <context>
    <name>StartGui::GeneralSettingsWidget</name>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="212"/>
      <source>Language</source>
      <translation>Jazyk</translation>
    </message>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="213"/>
      <source>Unit System</source>
      <translation>Jednotky</translation>
    </message>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="226"/>
      <source>Navigation Style</source>
      <translation>Styl navigace</translation>
    </message>
  </context>
  <context>
    <name>CmdStart</name>
    <message>
      <location filename="../../Manipulator.cpp" line="47"/>
      <location filename="../../Manipulator.cpp" line="48"/>
      <source>Start</source>
      <translation>Start</translation>
    </message>
    <message>
      <location filename="../../Manipulator.cpp" line="49"/>
      <source>Displays the Start in an MDI view</source>
      <translation>Zobrazí start v zobrazení MDI</translation>
    </message>
  </context>
  <context>
    <name>StartGui::StartView</name>
    <message>
      <location filename="../../StartView.cpp" line="289"/>
      <source>Empty file</source>
      <translation>Prázdný soubor</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="290"/>
      <source>Create a new empty FreeCAD file</source>
      <translation>Vytvořit prázdný soubor FreeCADu</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="293"/>
      <source>Open File</source>
      <translation>Otevřít soubor</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="294"/>
      <source>Open an existing CAD file or 3D model</source>
      <translation>Otevřít existující CAD soubor nebo 3D model</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="297"/>
      <source>Parametric Part</source>
      <translation>Parametrický díl</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="298"/>
      <source>Create a part with the Part Design workbench</source>
      <translation>Vytvořit díl v prostředí návrhu dílu</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="301"/>
      <source>Assembly</source>
      <translation>Sestava</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="302"/>
      <source>Create an assembly project</source>
      <translation>Vytvořit projekt sestavy</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="305"/>
      <source>2D Draft</source>
      <translation>2D návrh</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="306"/>
      <source>Create a 2D Draft with the Draft workbench</source>
      <translation>Vytvořit 2D návrh v prostředí návrhu</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="309"/>
      <source>BIM/Architecture</source>
      <translation>BIM/Architektura</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="310"/>
      <source>Create an architectural project</source>
      <translation>Vytvořit projekt architektury</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="525"/>
      <source>New File</source>
      <translation>Nový soubor</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="526"/>
      <source>Examples</source>
      <translation>Příklady</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="527"/>
      <source>Recent Files</source>
      <translation>Nedávné soubory</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="530"/>
      <source>Open first start setup</source>
      <translation>Otevřít nastavení prvního spuštění</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="532"/>
      <source>Don't show this Start page again (start with blank screen)</source>
      <translation>Nezobrazovat příště tuto úvodní stránku (začít s prázdnou obrazovkou)</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../StartView.cpp" line="519"/>
      <source>Start</source>
      <translation>Start</translation>
    </message>
  </context>
  <context>
    <name>StartGui::ThemeSelectorWidget</name>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="113"/>
      <source>FreeCAD Classic</source>
      <translation>Klasický FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="114"/>
      <source>FreeCAD Dark</source>
      <translation>Tmavý FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="115"/>
      <source>FreeCAD Light</source>
      <translation>Světlý FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="238"/>
      <source>Theme</source>
      <translation>Motiv</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="239"/>
      <source>Looking for more themes? You can obtain them using &lt;a href="freecad:Std_AddonMgr"&gt;Addon Manager&lt;/a&gt;.</source>
      <translation>Hledáte více motivů? Můžete je získat prostřednictvím &lt;a href="freecad:Std_AddonMgr"&gt;Správce doplňků&lt;/a&gt;.</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="241"/>
      <source>FreeCAD Dark</source>
      <comment>Visual theme name</comment>
      <translation>Tmavý FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="242"/>
      <source>FreeCAD Light</source>
      <comment>Visual theme name</comment>
      <translation>Světlý FreeCAD</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="243"/>
      <source>FreeCAD Classic</source>
      <comment>Visual theme name</comment>
      <translation>Klasický FreeCAD</translation>
    </message>
  </context>
</TS>
